@@ -223,7 +223,7 @@ def access_info(set):
     return PA
 
 
-def build_set_data(relic_list):
+def build_set_data(relic_list, pd_file=None):
     # List of prime parts
     part_list = []
 
@@ -256,7 +256,7 @@ def build_set_data(relic_list):
             if set_list[i][0].split()[0] == part_list[j].split()[0]:
                 set_list[i].append(part_list[j])
 
-    price_data = get_price_data()
+    price_data = get_price_data(pd_file)
 
     for i, _ps in enumerate(set_list):
         parts = {'parts': {}}
@@ -390,15 +390,18 @@ def build_relic_data(relic_data, set_data):
     return relic_data
 
 
-def build_json_files():
+def build_json_files(pd_file=None):
     relic_list = build_relic_list()
-    set_data = build_set_data(relic_list)
+    set_data = build_set_data(relic_list, pd_file)
     relic_data = build_relic_data(relic_list, set_data)
 
     return json.loads(json.dumps(relic_data)), json.loads(json.dumps(set_data))
 
 
-def get_price_data():
-    soup = BeautifulSoup(requests.get('http://23.95.43.245/history/').text, 'html.parser')
-    return requests.get(sorted(['http://23.95.43.245/history/' + node.get('href')
-                                for node in soup.find_all('a') if node.get('href').endswith('json')])[-1]).json()
\ No newline at end of file
+def get_price_data(pd_file):
+    if pd_file is None:
+        soup = BeautifulSoup(requests.get('http://23.95.43.245/history/').text, 'html.parser')
+        return requests.get(sorted(['http://23.95.43.245/history/' + node.get('href')
+                                    for node in soup.find_all('a') if node.get('href').endswith('json')])[-1]).json()
+    else:
+        return requests.get(f"http://23.95.43.245/history/{pd_file}").json()
\ No newline at end of file
